@@ -12,12 +12,12 @@ $Id$
 
 from __future__ import with_statement
 
-__version__='$Revision$'
+__version__='1.0.1'
 
 #from math import pi, sqrt
 
 import numpy
-from numpy.oldnumeric import around, bitwise_and, bitwise_or
+from numpy import around, bitwise_and, bitwise_or
 from numpy import abs, add, alltrue, array, ceil, clip, cos, fft, flipud, \
         floor, exp, hstack, Infinity, linspace, multiply, nonzero, pi, \
         repeat, sin, sqrt, subtract, tile, zeros, sum, max
